==> zend-framework_1.9.4.orig.tar.gz: zend-framework-1.9.4/tests/Zend/Service/Delicious/AllTests.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Service_Delicious
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: AllTests.php 17363 2009-08-03 07:40:18Z bkarwin $
 */


if (!defined('PHPUnit_MAIN_METHOD')) {
    define('PHPUnit_MAIN_METHOD', 'Zend_Service_Delicious_AllTests::main');
}

/**
 * Test helper
 */
require_once dirname(__FILE__) . '/../../../TestHelper.php';

/**
 * Exclude from code coverage report
 */
PHPUnit_Util_Filter::addFileToFilter(__FILE__);


/**
 * @category   Zend
 * @package    Zend_Service_Delicious
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @group      Zend_Service
 * @group      Zend_Service_Delicious
 */
class Zend_Service_Delicious_AllTests
{
    /**
     * Runs this test suite
     *
     * @return void
     */
    public static function main()
    {
        PHPUnit_TextUI_TestRunner::run(self::suite());
    }

    /**
     * Creates and returns this test suite
     *
     * @return PHPUnit_Framework_TestSuite
     */
    public static function suite()
    {
        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Service_Delicious');

        if (!defined('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED') ||
            !constant('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED')) {

            /**
             * @see Zend_Service_Delicious_SkipTests
             */
            require_once 'Zend/Service/Delicious/SkipTests.php';
            $suite->addTestSuite('Zend_Service_Delicious_SkipTests');

        } else {

            /**
             * @see Zend_Service_Delicious_PublicDataTest
             */
            require_once 'Zend/Service/Delicious/PublicDataTest.php';
            $suite->addTestSuite('Zend_Service_Delicious_PublicDataTest');

            /**
             * @see Zend_Service_Delicious_PrivateDataTest
             */
            require_once 'Zend/Service/Delicious/PrivateDataTest.php';
            $suite->addTestSuite('Zend_Service_Delicious_PrivateDataTest');
        }

        /**
         * @see Zend_Service_Delicious_SimplePostTest
         */
        require_once 'Zend/Service/Delicious/SimplePostTest.php';
        $suite->addTestSuite('Zend_Service_Delicious_SimplePostTest');

        /**
         * @see Zend_Service_Delicious_PostTest
         */
        require_once 'Zend/Service/Delicious/PostTest.php';
        $suite->addTestSuite('Zend_Service_Delicious_PostTest');

        return $suite;
    }
}


if (PHPUnit_MAIN_METHOD == 'Zend_Service_Delicious_AllTests::main') {
    Zend_Service_Delicious_AllTests::main();
}

==> zend-framework_1.10.3.orig.tar.gz: zend-framework-1.10.3/tests/Zend/Service/Delicious/AllTests.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Service_Delicious
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: AllTests.php 20096 2010-01-06 02:05:09Z bkarwin $
 */

require_once dirname(dirname(dirname(dirname(__FILE__)))) . DIRECTORY_SEPARATOR . 'TestHelper.php';

if (!defined('PHPUnit_MAIN_METHOD')) {
    define('PHPUnit_MAIN_METHOD', 'Zend_Service_Delicious_AllTests::main');
}

if (defined('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED') &&
    constant('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED')) {
    require_once 'Zend/Service/Delicious/PublicDataTest.php';
    require_once 'Zend/Service/Delicious/PrivateDataTest.php';
} else {
    require_once 'Zend/Service/Delicious/SkipTests.php';
}

require_once 'Zend/Service/Delicious/SimplePostTest.php';
require_once 'Zend/Service/Delicious/PostTest.php';

/**
 * @category   Zend
 * @package    Zend_Service_Delicious
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @group      Zend_Service
 * @group      Zend_Service_Delicious
 */
class Zend_Service_Delicious_AllTests
{
    /**
     * Runs this test suite
     *
     * @return void
     */
    public static function main()
    {
        PHPUnit_TextUI_TestRunner::run(self::suite());
    }

    /**
     * Creates and returns this test suite
     *
     * @return PHPUnit_Framework_TestSuite
     */
    public static function suite()
    {
        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Service_Delicious');

        if (defined('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED') &&
            constant('TESTS_ZEND_SERVICE_DELICIOUS_ENABLED')) {
            $suite->addTestSuite('Zend_Service_Delicious_PublicDataTest');
            $suite->addTestSuite('Zend_Service_Delicious_PrivateDataTest');
        } else {
            $suite->addTestSuite('Zend_Service_Delicious_SkipTests');
        }

        $suite->addTestSuite('Zend_Service_Delicious_SimplePostTest');

        $suite->addTestSuite('Zend_Service_Delicious_PostTest');

        return $suite;
    }
}


if (PHPUnit_MAIN_METHOD == 'Zend_Service_Delicious_AllTests::main') {
    Zend_Service_Delicious_AllTests::main();
}
